# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# Select the appropriate system speller
%if 0%{?fedora} > 8 || 0%{?rhel} > 5
%global speller hunspell
%else
%global speller aspell
%endif

# Old hunspell versions need a workaround
%global hunspell_version %((hunspell -v 2>/dev/null || echo 1.2.8@) | awk '{ print substr($NF, 1, length($NF)-1); exit }')

Name:		perl-Test-Spelling
Version:	0.20
Release:	5.%{__distinit}%{__distvers}
Summary:	Check for spelling errors in POD files
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Test-Spelling/
Source0:	http://search.cpan.org/CPAN/authors/id/S/SA/SARTAK/Test-Spelling-%{version}.tar.gz
Patch0:		Test-Spelling-0.20-hunspell.patch
Patch1:		Test-Spelling-0.17-C-locale.patch
Patch3:		Test-Spelling-0.17-old-Test::More.patch
Patch4:		Test-Spelling-0.17-stopwords.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gawk
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	%{speller}
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IPC::Run3) >= 0.044
BuildRequires:	perl(Pod::Spell) >= 1.01
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Text::Wrap)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	%{speller}-en
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Tester)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	%{speller}
Requires:	perl(Carp)

%description
"Test::Spelling" lets you check the spelling of a POD file, and report
its results in standard "Test::Simple" fashion.

%prep
%setup -q -n Test-Spelling-%{version}

# Patch for hunspell if necessary
%if "%{speller}" == "hunspell"
%patch0
%endif

# hunspell in F-9 and F-10 doesn't treat "C" locale as "en_US"
# so force it to do so
%if %(perl -e 'print ((%{hunspell_version} lt 1.2.8) ? 1 : 0);' 2>/dev/null || echo 0)
%patch1
%endif

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch3
%endif

# Some old distributions need extra stopwords due to poor dictionary coverage
%patch4

# Force the author test to run too
mkdir inc/.author

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
LANG=en_US make test

%clean
rm -rf %{buildroot}

%files
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Spelling.3*

%changelog
* Thu Oct  6 2016 Paul Howarth <paul@city-fan.org> - 0.20-5
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Oct  7 2014 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Add a sorted list of your most commonly misspelled words to the end of
    all_pod_files_spelling_ok to aid stopword list creation and bulk
    correction
- Classify buildreqs by usage
- Update hunspell preference patch

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 0.19-5
- Drop %%defattr, redundant since rpm 4.4

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 0.19-2
- Perl 5.18 rebuild

* Sun May  5 2013 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19:
  - For more consistent results, avoid using the user's local aspell dictionary
    (CPAN RT#84869)
- Update hunspell preference patch

* Fri Apr 26 2013 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18:
  - Work around Pod::Spell limitations
  - Improve case handling
  - Improve test failure reporting
  - Include more useful info in Test-Spelling's own test suite

* Mon Jan 28 2013 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17:
  - Use IPC::Run3 instead of IPC::Open3
- Run test suite with LANG=en_US to ensure correct dictionaries are used
- Update patches as needed

* Fri Dec 21 2012 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16:
  - Allow use of a custom POD parser rather than Pod::Spell using
    set_pod_parser
- Drop support for perl < 5.8.3
- Re-diff patches as necessary

* Sat Jun 23 2012 Paul Howarth <paul@city-fan.org> - 0.15-3
- BR: perl(base), perl(Cwd), perl(Exporter), perl(ExtUtils::MakeMaker),
  perl(File::Spec) and perl(Test::Builder)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Never need aspell-en-gb

* Tue Aug 23 2011 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15:
  - Begin adding actual tests (hilariously, adding the suggested t/pod-spell.t
    to this dist to test itself found a typo: "stopwards")
- BR: perl(Test::Tester) and a suitable English dictionary
- Add patch to support building with perl < 5.8.3
- Add patch to support building with Test::More < 0.88
- Add patch for extra stopwords on old distributions

* Mon Aug  8 2011 Paul Howarth <paul@city-fan.org> - 0.14-3
- Add hack for hunspell < 1.2.8, which doesn't treat the "C" locale as "en_US"
  by default

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.14-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May 27 2011 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14:
  - Fix an error when using add_stopwords("constant","strings") (CPAN RT#68471)

* Wed Apr 27 2011 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13:
  - Make alternatives checking more robust by reading the spellchecker's STDERR

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12:
  - Best Practical has taken over maintainership of this module
  - Try various spellcheck programs instead of hardcoding the ancient `spell`
    (CPAN RT#56483)
  - Remove temporary files more aggressively (CPAN RT#41586)
  - Fixed by not creating them at all - instead we now use IPC::Open3
  - Remove suggestion to use broken `aspell -l` (CPAN RT#28967)
  - Add set_pod_file_filter for skipping translations, etc. (CPAN RT#63755)
  - Skip tests in all_pod_files_spelling_ok if there is no working spellchecker
  - Provide a has_working_spellchecker so you can skip your own tests if
    there's no working spellchecker
  - Switch to Module::Install
  - Rewrite and modernize a lot of the documentation
  - Decruftify code, such as by using Exporter and lexical filehandles
  - Support .plx files
- This release by SARTAK -> update source URL
- Rewrite hunspell patch to just favour hunspell over aspell
- Drop File::Temp requirement, so we can run on RHL-9/RHEL-3 now
- Nobody else likes macros for commands

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.11-9
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 17 2010 Paul Howarth <paul@city-fan.org> - 0.11-8
- Fix dist tag for RHEL-6 Beta

* Fri Jan 29 2010 Paul Howarth <paul@city-fan.org> - 0.11-7
- Patch to use hunspell rather than aspell with perl 5.10 onwards
  (F-9 onwards - #508643)
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu Nov 26 2009 Paul Howarth <paul@city-fan.org> - 0.11-6
- Import from Fedora
- Buildreq File::Temp >= 0.14, needed for OO interface used in this module

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.11-3
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.11-2
- Rebuild for new perl

* Tue Dec 19 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.11-1
- First build
